@@ -32,11 +32,9 @@
 #include "gedit-output-window.h"
 #include "gconf-search-dialog.h"
 #include <gconf/gconf.h>
-#include <libintl.h>
 #include <string.h>
 
 
-
 /* Property IDs */
 enum
 {
@@ -56,7 +54,7 @@ static void		gconf_editor_window_get_property	(GObject          *object,
 
 static GConfClient* 	gconf_editor_window_get_client 		(int type);
 
-static GObjectClass *parent_class;
+G_DEFINE_TYPE(GConfEditorWindow, gconf_editor_window, GTK_TYPE_WINDOW)
 
 void
 gconf_editor_window_popup_error_dialog (GtkWindow   *parent,
@@ -383,9 +381,6 @@ gconf_editor_window_output_window_changed (GtkWidget *widget, gchar *key, gpoint
 	gconf_editor_window_go_to (window, key);
 }
 
-
-
-
 static void
 gconf_editor_window_about_window (GtkAction *action, GtkWidget *callback_data)
 {
@@ -399,16 +394,20 @@ gconf_editor_window_about_window (GtkAction *action, GtkWidget *callback_data)
 		"Shaun McCance <shaunm@gnome.org>",
 		NULL
 	};
-	const gchar *translator_credits = _("translator-credits");
 
 	gtk_show_about_dialog (GTK_WINDOW (callback_data),
+#if GTK_CHECK_VERSION (2, 11, 0)
+                              "program-name", _("Configuration Editor"),
+#else
+                              "name", _("Configuration Editor"),
+#endif
 			      "version", VERSION,
 			      "copyright", "Copyright \xc2\xa9 2001-2004 Anders Carlsson",
 			      "comments", _("An editor for the GConf configuration system."),
 			      "authors", authors,
 			      "documenters", documenters,
-			      "translator_credits", strcmp(translator_credits, "translator-credits") != 0 ? translator_credits : NULL,
-			      "logo_icon_name", "gconf-editor",
+			      "translator-credits", _("translator-credits"),
+			      "logo-icon-name", "gconf-editor",
 			      NULL);
 }	
 
@@ -1375,7 +1374,7 @@ gconf_editor_window_get_property (GObject      *object,
 static void
 gconf_editor_window_finalize (GObject *object)
 {
-        GConfEditorWindow *window = (GConfEditorWindow *) object;
+	GConfEditorWindow *window = GCONF_EDITOR_WINDOW(object);
 	GConfClient       *client;
 
 	client = gconf_client_get_default ();
@@ -1390,15 +1389,16 @@ gconf_editor_window_finalize (GObject *object)
 
 	g_object_unref (client);
 
-	/* FIXME: unref client? */
-
-        parent_class->finalize (object);
+	/* FIXME: unref client?*/
+	
+	G_OBJECT_CLASS(gconf_editor_window_parent_class)->finalize (object);
+    
 }
 
 static void
 gconf_editor_window_class_init (GConfEditorWindowClass *klass)
 {
-	GObjectClass *object_class = (GObjectClass *) klass;
+	GObjectClass *object_class = G_OBJECT_CLASS(klass);
 
 	object_class->set_property = gconf_editor_window_set_property;
 	object_class->get_property = gconf_editor_window_get_property;
@@ -1406,18 +1406,45 @@ gconf_editor_window_class_init (GConfEditorWindowClass *klass)
 
 	g_object_class_install_property (object_class, PROP_TYPE,
 					 g_param_spec_int ("type",
-					 _("Type"),
-					 _("The Configuration Editor window type."),
+					 "Type",
+					 "The Configuration Editor window type.",
 					 GCONF_EDITOR_WINDOW_TYPE_NORMAL, GCONF_EDITOR_WINDOW_TYPE_MANDATORY,
 					 GCONF_EDITOR_WINDOW_TYPE_NORMAL, 
 					 (G_PARAM_WRITABLE |
 					 G_PARAM_CONSTRUCT_ONLY)));
-
-
-	parent_class = g_type_class_peek_parent (klass);
 }
 
+static void
+tree_view_style_set_cb (GtkWidget *widget,
+                        GtkStyle *previous_style,
+                        GObject *cell)
+{
+        GdkPixbuf *folder_open = NULL, *folder_closed = NULL;
+        int w, h;
 
+        if (gtk_icon_size_lookup_for_settings (gtk_widget_get_settings (widget),
+                                               GTK_ICON_SIZE_MENU,
+                                               &w, &h)) {
+                GtkIconTheme *theme;
+
+                theme = gtk_icon_theme_get_for_screen (gtk_widget_get_screen (widget));
+                
+                folder_open = gtk_icon_theme_load_icon (theme, "folder-open", w, GTK_ICON_LOOKUP_GENERIC_FALLBACK, NULL);
+                folder_closed = gtk_icon_theme_load_icon (theme, "folder", w, GTK_ICON_LOOKUP_GENERIC_FALLBACK, NULL);
+        }
+
+        g_object_set (cell,
+                      "pixbuf-expander-open", folder_open,
+                      "pixbuf-expander-closed", folder_closed,
+                      "pixbuf", folder_closed,
+                      NULL);
+        if (folder_open) {
+                g_object_unref (folder_open);
+        }
+        if (folder_closed) {
+                g_object_unref (folder_closed);
+        }
+}
 
 static void
 gconf_editor_window_init (GConfEditorWindow *window)
@@ -1516,12 +1543,8 @@ gconf_editor_window_init (GConfEditorWindow *window)
 	column = gtk_tree_view_column_new ();
 
 	cell = gtk_cell_renderer_pixbuf_new ();
+        g_signal_connect (window->tree_view, "style-set", G_CALLBACK (tree_view_style_set_cb), cell);
 	gtk_tree_view_column_pack_start (column, cell, FALSE);
-	gtk_tree_view_column_set_attributes (column, cell,
-					     "pixbuf", GCONF_TREE_MODEL_CLOSED_ICON_COLUMN,
-					     "pixbuf_expander_closed", GCONF_TREE_MODEL_CLOSED_ICON_COLUMN,
-					     "pixbuf_expander_open", GCONF_TREE_MODEL_OPEN_ICON_COLUMN,
-					     NULL);
 	cell = gtk_cell_renderer_text_new ();
 	gtk_tree_view_column_pack_start (column, cell, TRUE);
 	gtk_tree_view_column_set_attributes (column, cell,
@@ -1563,9 +1586,10 @@ gconf_editor_window_init (GConfEditorWindow *window)
 	gtk_tree_view_column_set_title (column, _("Name"));
 
 	cell = gtk_cell_renderer_pixbuf_new ();
+        g_object_set (cell, "stock-size", GTK_ICON_SIZE_MENU, NULL);
 	gtk_tree_view_column_pack_start (column, cell, FALSE);
 	gtk_tree_view_column_set_attributes (column, cell,
-					     "pixbuf", GCONF_LIST_MODEL_ICON_COLUMN,
+					     "icon-name", GCONF_LIST_MODEL_ICON_NAME_COLUMN,
 					     NULL);
 
 	gtk_tree_view_column_set_resizable (column, TRUE);
@@ -1729,27 +1753,3 @@ gconf_editor_window_init (GConfEditorWindow *window)
 	gconf_editor_window_setup_ui_prefs_handler (window);
 }
 
-GType
-gconf_editor_window_get_type (void)
-{
-	static GType object_type = 0;
-
-	if (!object_type) {
-		static const GTypeInfo object_info = {
-			sizeof (GConfEditorWindowClass),
-			NULL,		/* base_init */
-			NULL,		/* base_finalize */
-			(GClassInitFunc) gconf_editor_window_class_init,
-			NULL,		/* class_finalize */
-			NULL,		/* class_data */
-			sizeof (GConfEditorWindow),
-			0,              /* n_preallocs */
-			(GInstanceInitFunc) gconf_editor_window_init
-		};
-
-		object_type = g_type_register_static (GTK_TYPE_WINDOW, "GConfEditorWindow", &object_info, 0);
-	}
-
-	return object_type;
-}
-
